;; Generated package description from web-server.el  -*- no-byte-compile: t -*-
(define-package "web-server" "0.1.2.0.20210218.221739" "Emacs Web Server" '((emacs "24.3")) :keywords '("http" "server" "network") :authors '(("Eric Schulte" . "schulte.eric@gmail.com")) :maintainer '("Eric Schulte" . "schulte.eric@gmail.com") :url "https://github.com/eschulte/emacs-web-server")
